@@ -413,7 +413,11 @@ class Scheduler(object):
                             except KeyError:
                                 logger.debug("Update Task %s with options=%s"
                                              % (t.id, t.options))
-                                self.task_list.update(t.id, options=t.options)
+                                self.task_list.update(
+                                    t.id,
+                                    options=t.options,
+                                    redo_interval=t.redo_interval,
+                                )
                         except StorageEngineError as e:
                             # Just log the error and continue with other tasks
                             logger.error(e.message)
@@ -882,6 +886,7 @@ class WorkerPool(object):
             # Put function result into output queue as a Message
             out.put(Message(MSG_TYPE_RESP, res))
         except Exception as e:
+            e = Exception("%s: %s" % (type(e), e))
             out.put(Message(MSG_TYPE_ERROR, e))
             logger.exception(e)
         except KeyboardInterrupt:
